==> qt-creator-1.0.0-src.zip: qt-creator-1.0.0-src/src/libs/utils/filewizarddialog.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact:  Qt Software Information (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
**************************************************************************/

#ifndef FILEWIZARDDIALOG_H
#define FILEWIZARDDIALOG_H

#include "utils_global.h"

#include <QtGui/QWizard>

namespace Core {
namespace Utils {

class FileWizardPage;

/*
   Standard wizard for a single file letting the user choose name
   and path. Custom pages can be added via Core::IWizardExtension.
*/

class QWORKBENCH_UTILS_EXPORT FileWizardDialog : public QWizard {
    Q_OBJECT
    Q_DISABLE_COPY(FileWizardDialog)
public:
    explicit FileWizardDialog(QWidget *parent = 0);

    QString name() const;
    QString path() const;

public slots:
    void setPath(const QString &path);
    void setName(const QString &name);

private:
    FileWizardPage *m_filePage;
};

} // namespace Utils
} // namespace Core

#endif // FILEWIZARDDIALOG_H

==> qt-creator-1.2.1-src.zip: qt-creator-1.2.1-src/src/libs/utils/filewizarddialog.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://www.qtsoftware.com/contact.
**
**************************************************************************/

#ifndef FILEWIZARDDIALOG_H
#define FILEWIZARDDIALOG_H

#include "utils_global.h"

#include <QtGui/QWizard>

namespace Core {
namespace Utils {

class FileWizardPage;

/*
   Standard wizard for a single file letting the user choose name
   and path. Custom pages can be added via Core::IWizardExtension.
*/

class QTCREATOR_UTILS_EXPORT FileWizardDialog : public QWizard {
    Q_OBJECT
    Q_DISABLE_COPY(FileWizardDialog)
public:
    explicit FileWizardDialog(QWidget *parent = 0);

    QString name() const;
    QString path() const;

public slots:
    void setPath(const QString &path);
    void setName(const QString &name);

private:
    FileWizardPage *m_filePage;
};

} // namespace Utils
} // namespace Core

#endif // FILEWIZARDDIALOG_H
